==> voreen-src-4.1.1-win.zip: voreen-src-4.1.1-win/modules/plotting/properties/colormapproperty.h <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2012 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#ifndef VRN_COLORMAPPROPERTY_H
#define VRN_COLORMAPPROPERTY_H

#include "voreen/core/properties/templateproperty.h"
#include "../datastructures/colormap.h"

namespace voreen {

/**
 * This Property holds a ColorMap.
 *
 */
class ColorMapProperty : public TemplateProperty<ColorMap> {
public:
    ColorMapProperty(const std::string& id, const std::string& guiText, ColorMap value = ColorMap::createColdHot(),
        Processor::InvalidationLevel invalidationLevel=Processor::INVALID_RESULT);

    virtual ~ColorMapProperty() {}

    virtual std::string getTypeDescription() const;

    /**
     * @see Property::serialize
     */
    virtual void serialize(XmlSerializer& s) const;

    /**
     * @see Property::deserialize
     */
    virtual void deserialize(XmlDeserializer& s);

};

}   // namespace

#endif

==> voreen-src-4.2.1-win.zip: voreen-src-4.2.1-win/modules/plotting/properties/colormapproperty.h <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2013 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#ifndef VRN_COLORMAPPROPERTY_H
#define VRN_COLORMAPPROPERTY_H

#include "voreen/core/voreencoreapi.h"
#include "voreen/core/properties/templateproperty.h"

#include "../datastructures/colormap.h"

namespace voreen {

/**
 * This Property holds a ColorMap.
 *
 */
class VRN_CORE_API ColorMapProperty : public TemplateProperty<ColorMap> {
public:
    ColorMapProperty(const std::string& id, const std::string& guiText, ColorMap value = ColorMap::createColdHot(),
        Processor::InvalidationLevel invalidationLevel=Processor::INVALID_RESULT);

    virtual ~ColorMapProperty() {}

    virtual std::string getTypeDescription() const;

    /**
     * @see Property::serialize
     */
    virtual void serialize(XmlSerializer& s) const;

    /**
     * @see Property::deserialize
     */
    virtual void deserialize(XmlDeserializer& s);

};

}   // namespace

#endif
